/**
    (C) Copyright 2012 Dominik Wagenfuehr

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef GAME_HH
#define GAME_HH

#include <string>

class Game
{
  public:
    /// Startet das Spiel.
    /**
     * Bestimmt anhand des Parameters, welcher Bot benutzt wird.
     * @param strategy Der erste Konsolenparameter, der die Strategie
     * des Bots bestimmt.
     * @return true, wenn alles okay verlief.
     */
    bool start( const std::string& strategy );

  private:
    /// Liest eine Eingabe vom Benutzer.
    /**
     * Das Einlesen der Eingabe geschieht über STDIN.
     * @return Eingabe des Benutzers
     */
    std::string readInput() const;

    /// Interpretiert die Benutzereingabe.
    /**
     * Die Eingabe muss eine Zahl zwischen 0 und 1000 sein.
     * Ist der Wert ungültig, bricht das Programm ab.
     * @param input Die Eingabe des Benutzers.
     * @return Zahlewert zwischen 0 und 1000, oder negativ, wenn Ende.
     */
    int parseInput( const std::string& input ) const;
};

#endif // GAME_HH
